@@ -2,8 +2,8 @@
 
 /*
  * $Author: tom $
- * $Date: 2011/05/16 22:35:16 $
- * $Revision: 1.218 $
+ * $Date: 2021/12/16 00:34:02 $
+ * $Revision: 1.225 $
  */
 
 /*
@@ -20,8 +20,8 @@ DeclareCDKObjects (ENTRY, Entry, setCdk, String);
 CDKENTRY *newCDKEntry (CDKSCREEN *cdkscreen,
 		       int xplace,
 		       int yplace,
-		       char *title,
-		       char *label,
+		       const char *title,
+		       const char *label,
 		       chtype fieldAttr,
 		       chtype filler,
 		       EDisplayType dispType,
@@ -87,7 +87,7 @@ CDKENTRY *newCDKEntry (CDKSCREEN *cdkscreen,
    alignxy (cdkscreen->window, &xpos, &ypos, boxWidth, boxHeight);
 
    /* Make the label window. */
-   entry->win = subwin (cdkscreen->window, boxHeight, boxWidth, ypos, xpos);
+   entry->win = newwin (boxHeight, boxWidth, ypos, xpos);
    if (entry->win == 0)
    {
       destroyCDKObject (entry);
@@ -151,11 +151,11 @@ CDKENTRY *newCDKEntry (CDKSCREEN *cdkscreen,
    /* Do we want a shadow? */
    if (shadow)
    {
-      entry->shadowWin = subwin (cdkscreen->window,
-				 boxHeight,
-				 boxWidth,
-				 ypos + 1,
-				 xpos + 1);
+      entry->shadowWin = newwin (
+				   boxHeight,
+				   boxWidth,
+				   ypos + 1,
+				   xpos + 1);
    }
 
    registerCDKObject (cdkscreen, vENTRY, entry);
@@ -170,7 +170,6 @@ CDKENTRY *newCDKEntry (CDKSCREEN *cdkscreen,
  */
 char *activateCDKEntry (CDKENTRY *entry, chtype *actions)
 {
-   chtype input = 0;
    boolean functionKey;
    char *ret = 0;
 
@@ -181,7 +180,7 @@ char *activateCDKEntry (CDKENTRY *entry, chtype *actions)
    {
       for (;;)
       {
-	 input = (chtype)getchCDKObject (ObjOf (entry), &functionKey);
+	 chtype input = (chtype)getchCDKObject (ObjOf (entry), &functionKey);
 
 	 /* Inject the character into the widget. */
 	 ret = injectCDKEntry (entry, input);
@@ -221,14 +220,13 @@ char *activateCDKEntry (CDKENTRY *entry, chtype *actions)
 static void setPositionToEnd (CDKENTRY *entry)
 {
    int stringLen;
-   int charCount;
 
    stringLen = (int)strlen (entry->info);
    if (stringLen >= entry->fieldWidth)
    {
       if (stringLen < entry->max)
       {
-	 charCount = entry->fieldWidth - 1;
+	 int charCount = entry->fieldWidth - 1;
 	 entry->leftChar = stringLen - charCount;
 	 entry->screenCol = charCount;
       }
@@ -252,8 +250,6 @@ static int _injectCDKEntry (CDKOBJS *object, chtype input)
 {
    CDKENTRY *widget = (CDKENTRY *)object;
    int ppReturn = 1;
-   int x;
-   char holder;
    char *ret = unknownString;
    bool complete = FALSE;
 
@@ -306,7 +302,7 @@ static int _injectCDKEntry (CDKOBJS *object, chtype input)
 	    }
 	    else
 	    {
-	       holder = widget->info[currPos];
+	       char holder = widget->info[currPos];
 	       widget->info[currPos] = widget->info[currPos + 1];
 	       widget->info[currPos + 1] = holder;
 	       drawCDKEntryField (widget);
@@ -370,6 +366,8 @@ static int _injectCDKEntry (CDKOBJS *object, chtype input)
 	       {
 		  if (currPos < infoLength)
 		  {
+		     int x;
+
 		     for (x = currPos; x < infoLength; x++)
 		     {
 			widget->info[x] = widget->info[x + 1];
@@ -559,7 +557,6 @@ static void _moveCDKEntry (CDKOBJS *object,
 static void CDKEntryCallBack (CDKENTRY *entry, chtype character)
 {
    int plainchar = filterByDisplayType (entry->dispType, character);
-   size_t temp;
 
    if (plainchar == ERR ||
        ((int)strlen (entry->info) >= entry->max))
@@ -585,7 +582,7 @@ static void CDKEntryCallBack (CDKENTRY *entry, chtype character)
       else
       {
 	 /* Update the character pointer. */
-	 temp = strlen (entry->info);
+	 size_t temp = strlen (entry->info);
 	 entry->info[temp] = (char)plainchar;
 	 entry->info[temp + 1] = '\0';
 	 /* Do not update the pointer if it's the last character */
@@ -610,7 +607,7 @@ void cleanCDKEntry (CDKENTRY *entry)
    cleanChar (entry->info, entry->infoWidth, '\0');
 
    /* Clean the entry screen field. */
-   mvwhline (entry->fieldWin, 0, 0, entry->filler, width);
+   (void)mvwhline (entry->fieldWin, 0, 0, entry->filler, width);
 
    /* Reset some variables. */
    entry->screenCol = 0;
@@ -658,31 +655,34 @@ static void _drawCDKEntry (CDKOBJS *object, boolean Box)
  */
 static void drawCDKEntryField (CDKENTRY *entry)
 {
-   int infoLength = 0;
    int x = 0;
 
+   /* Set background color and attributes of the entry field */
+   wbkgd (entry->fieldWin, entry->fieldAttr);
+
    /* Draw in the filler characters. */
-   mvwhline (entry->fieldWin, 0, x, entry->filler, entry->fieldWidth);
+   (void)mvwhline (entry->fieldWin, 0, x, entry->filler | entry->fieldAttr, entry->fieldWidth);
 
    /* If there is information in the field. Then draw it in. */
    if (entry->info != 0)
    {
-      infoLength = (int)strlen (entry->info);
+      int infoLength = (int)strlen (entry->info);
 
       /* Redraw the field. */
       if (isHiddenDisplayType (entry->dispType))
       {
 	 for (x = entry->leftChar; x < infoLength; x++)
 	 {
-	    mvwaddch (entry->fieldWin, 0, x - entry->leftChar, entry->hidden);
+	    (void)mvwaddch (entry->fieldWin, 0, x - entry->leftChar,
+			    entry->hidden | entry->fieldAttr);
 	 }
       }
       else
       {
 	 for (x = entry->leftChar; x < infoLength; x++)
 	 {
-	    mvwaddch (entry->fieldWin, 0, x - entry->leftChar,
-		      CharOf (entry->info[x]) | entry->fieldAttr);
+	    (void)mvwaddch (entry->fieldWin, 0, x - entry->leftChar,
+			    CharOf (entry->info[x]) | entry->fieldAttr);
 	 }
       }
       wmove (entry->fieldWin, 0, entry->screenCol);
@@ -738,7 +738,7 @@ static void _destroyCDKEntry (CDKOBJS *object)
  * This sets specific attributes of the entry field.
  */
 void setCDKEntry (CDKENTRY *entry,
-		  char *value,
+		  const char *value,
 		  int min,
 		  int max,
 		  boolean Box GCC_UNUSED)
@@ -752,10 +752,8 @@ void setCDKEntry (CDKENTRY *entry,
  * This removes the old information in the entry field and keeps the
  * new information given.
  */
-void setCDKEntryValue (CDKENTRY *entry, char *newValue)
+void setCDKEntryValue (CDKENTRY *entry, const char *newValue)
 {
-   int copychars = 0;
-
    /* If the pointer sent in is the same pointer as before, do nothing. */
    if (entry->info != newValue)
    {
@@ -772,7 +770,7 @@ void setCDKEntryValue (CDKENTRY *entry, char *newValue)
       else
       {
 	 /* Determine how many characters we need to copy. */
-	 copychars = MINIMUM ((int)strlen (newValue), entry->max);
+	 int copychars = MINIMUM ((int)strlen (newValue), entry->max);
 
 	 /* OK, erase the old value, and copy in the new value. */
 	 cleanChar (entry->info, entry->max, '\0');
